"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAgendaEvents = exports.getMonthEvents = void 0;

var _dayjs = _interopRequireDefault(require("dayjs"));

var _react = require("react");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useAgendaEvents = (currentMonth, events) => {
  return (0, _react.useMemo)(() => {
    const markedDays = {};
    const monthStartingDay = (0, _dayjs.default)(currentMonth).startOf('month').startOf('day');
    const monthEndingDay = (0, _dayjs.default)(currentMonth).endOf('month').endOf('day');
    events.forEach(event => {
      if ((0, _dayjs.default)(event.endDate).isBefore((0, _dayjs.default)(event.startDate))) {
        throw new Error(`${event.name} startDate must be previous to endDate`);
      }

      if ((0, _dayjs.default)(event.endDate).isBefore(monthStartingDay)) {
        // previous month event
        return;
      }

      if ((0, _dayjs.default)(event.startDate).isAfter(monthEndingDay)) {
        // future month event
        return;
      }

      let currentDay = (0, _dayjs.default)(event.startDate).isBefore(monthStartingDay) ? monthStartingDay : (0, _dayjs.default)(event.startDate);
      const lastDay = (0, _dayjs.default)(event.endDate).isBefore(monthEndingDay) ? (0, _dayjs.default)(event.endDate) : monthEndingDay;

      while (currentDay.isSameOrBefore(lastDay, 'day')) {
        const dot = {
          color: event.color,
          selectedColor: event.color
        };
        const dayIndex = currentDay.format('YYYY-MM-DD');

        if (markedDays[dayIndex]) {
          var _markedDays$dayIndex$;

          (_markedDays$dayIndex$ = markedDays[dayIndex].dots) === null || _markedDays$dayIndex$ === void 0 ? void 0 : _markedDays$dayIndex$.push(dot);
          markedDays[dayIndex].events.push(event);
        } else {
          markedDays[dayIndex] = {
            dots: [dot],
            events: [event]
          };
        }

        currentDay = currentDay.add(1, 'day');
      }
    });
    return {
      markedDays
    };
  }, [currentMonth, events]);
};

exports.useAgendaEvents = useAgendaEvents;

const getMonthEvents = (currentMonth, events) => {
  return events.filter(event => {
    if ((0, _dayjs.default)(event.endDate).isBefore((0, _dayjs.default)(event.startDate))) {
      throw new Error(`${event.name} startDate must be previous to endDate`);
    }

    const monthStartingDay = (0, _dayjs.default)(currentMonth).startOf('month').startOf('day');
    const monthEndingDay = (0, _dayjs.default)(currentMonth).endOf('month').endOf('day');

    if ((0, _dayjs.default)(event.startDate).isBetween(monthStartingDay, monthEndingDay)) {
      return true;
    }

    return (0, _dayjs.default)(event.endDate).isBetween(monthStartingDay, monthEndingDay);
  });
};

exports.getMonthEvents = getMonthEvents;
//# sourceMappingURL=use-agenda-events.js.map